Invoice — Stisla

# Invoice

Order #12345

Order Summary

All items here cannot be deleted.

# | Item | Price | Quantity | Totals
--- | --- | --- | --- | ---
1 | Mouse Wireless | $10.99 | 1 | $10.99
2 | Keyboard Wireless | $20.00 | 3 | $60.00
3 | Headphone Blitz TDR-3000 | $600.00 | 1 | $600.00

Payment Method

The payment method that we provide is to make it easier for you to pay invoices.

Subtotal
$670.99
Shipping
$15

Total
$685.99